library file.memory;

import 'dart:async';

import 'package:file/file.dart';
import 'package:file/src/memory/memory.dart';
export 'package:file/src/memory/memory.dart';

/// An in-memory representation of a file system.
///
/// Can be used as a caching layer for an actual file system, as a mock, or to
/// create a default implementation.
class MemoryFileSystem implements FileSystem {
  final InMemoryDirectory _root;

  MemoryFileSystem([InMemoryDirectory root])
      : _root = root != null ? root : new InMemoryDirectory('');

  @override
  Directory getDirectory(String path) => new _MemoryDirectory(this, path);

  @override
  File getFile(String path) => new _MemoryFile(this, path);
}

class _MemoryDirectory implements Directory {
  final MemoryFileSystem _fs;
  final String _path;

  _MemoryDirectory(this._fs, this._path);

  @override
  Future<bool> get exists {
    return new Future.value(_fs._root.get(_path) is InMemoryDirectory);
  }
}

class _MemoryFile implements File {
  final MemoryFileSystem _fs;
  final String _path;

  _MemoryFile(this._fs, this._path);

  @override
  Future<bool> get exists {
    return new Future.value(_fs._root.get(_path) is InMemoryFile);
  }
}
