library file.src.memory;

abstract class InMemoryEntity {
  final String name;
  InMemoryDirectory _parent;

  InMemoryEntity(this.name);

  InMemoryDirectory get parent => _parent;
}

class InMemoryDirectory extends InMemoryEntity {
  final List<InMemoryEntity> _entities;

  InMemoryDirectory(
      String name, [
      List<InMemoryEntity> entities])
          : super(name),
            _entities = entities != null ? entities : <InMemoryEntity> [];

  /// Returns the entity at [path].
  ///
  /// If path contains a '/', will recursively search deeper within the
  /// directory tree, returning null if the path is invalid.
  InMemoryEntity get(String path) {
    if (!path.contains('/')) {
      return getNonRecursive(path);
    } else {
      var entity = this;
      for (final part in path.split('/')) {
        if (entity is! InMemoryDirectory) {
          return null;
        } else {
          entity = entity.getNonRecursive(part);
        }
      }
      return entity;
    }
  }

  /// Same as [get], but does not parse '/'.
  InMemoryEntity getNonRecursive(String path) {
    assert(!path.contains('/'));
    return _entities.firstWhere((e) => e.name == path, orElse: () => null);
  }
}

class InMemoryFile extends InMemoryEntity {
  InMemoryFile(String name) : super(name);
}
