library file.test.memory_test;

import 'package:file/memory.dart';
import 'package:test/test.dart';

void main() {
  group('MemoryFileSystem', () {
    MemoryFileSystem fs;

    test('works with a default fs', () async {
      fs = new MemoryFileSystem();
      final exists = await fs.getFile('hello.txt').exists;
      expect(exists, isFalse);
    });

    test('works with a supplied fs', () async {
      fs = new MemoryFileSystem(new InMemoryDirectory('', [
        new InMemoryFile('hello.txt')
      ]));
      final exists = await fs.getFile('hello.txt').exists;
      expect(exists, isTrue);
    });

    test('works with a deeper supplied fs', () async {
      final directory = new InMemoryDirectory('', [
        new InMemoryDirectory('usr', [
          new InMemoryFile('hello.txt')
        ])
      ]);

      fs = new MemoryFileSystem(directory);

      var exists = await fs.getDirectory('user').exists;
      expect(exists, isFalse);
      exists = await fs.getDirectory('usr').exists;
      expect(exists, isTrue);
      exists = await fs.getFile('usr/hello.txt').exists;
      expect(exists, isTrue);
    });
  });
}
